\name{FWright.landscape}
\alias{FWright.landscape}
\title{Calculates Wright's Fixation index at each locus in each population}

\description{
  Calculate F
  }
\usage{
  Fmat <- FWright.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\value{
  A matrix of population x locus measures of Wright's F
}
\seealso{
obs.het.landscape, exp.het.landscape, allelefreq.landscape, Fst.landscape
}
\examples{
  exampleland <- new.example.landscape()
  FWright.landscape(exampleland)
  exampleland <- simulate.landscape(exampleland, 4)
  FWright.landscape(exampleland)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{Fst.landscape}
\alias{Fst.landscape}
\title{Calculates population structure statistic for the entire landscape}

\description{
  Calculate Fst for each allele at each locus in the landscape.  If
  verb is set to TRUE, the function prints average Fst for loci and
  overall.
}
\usage{
  Fstmat <- Fst.landscape(rland,verb=F)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{verb}{determines whether there is verbose output}
}
\value{
A matrix with num alleles columns and num loci rows.  Each element
reflects the value of Fst for that allelexlocus combination.  NA is
assigned to alleles that are not present at a locus (either no longer
or ever)}
\details{
  Calculates Fst based upon the ratio of variance in allele frequency
  across subpopulations to the total variance in that allele's
  frequency.  Does not calculate Wright's other statistics.
}
\seealso{
obs.het.landscape, exp.het.landscape, FWright.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  Fst <- Fst.landscape(exampleland,verb=TRUE)
  Fst
  rm(exampleland,Fst)
}

\keyword{misc}

\eof
\name{allelecount.landscape}
\alias{allelecount.landscape}
\title{Calculate allele numbers (frequency in the statistical sense) at each locus in each population}

\description{
  Calculate allele counts}
\usage{
  hetmat <- exp.het.landscape(rland,tbl.out=F)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{tbl.out}{return as a (three-dimensional) table if TRUE.  If
  FALSE, return as a dataframe with categorical variables denoting the
  locus, population and allele.}
}
\value{
  Depends on the value of tbl.out.  See above.
}
\seealso{
allelefreq.landscape, obs.het.landscape, exp.het.landscape, Fwright.landscape, Fst.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  allelefreq.landscape(exampleland,tbl.out=TRUE)
  allelefreq.landscape(exampleland,tbl.out=FALSE)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{allelefreq.landscape}
\alias{allelefreq.landscape}
\title{Calculate allele frequencies at each locus in each population}

\description{
  Calculate allele frequencies}
\usage{
  hetmat <- exp.het.landscape(rland,tbl.out=F)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{tbl.out}{return as a (three-dimensional) table if TRUE.  If
  FALSE, return as a dataframe with categorical variables denoting the
  locus, population and allele.}
}
\value{
  Depends on the value of tbl.out.  See above.
}
\seealso{
obs.het.landscape, exp.het.landscape, Fwright.landscape, Fst.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  allelefreq.landscape(exampleland,tbl.out=TRUE)
  allelefreq.landscape(exampleland,tbl.out=FALSE)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{Components of Simulations}
\alias{advance.landscape}
\alias{carry.landscape}
\alias{extinct.landscape}
\alias{reproduce.landscape}
\alias{survive.landscape}
\title{Code components to simulate a landscape}

\description{
  These functions can be used to construct custom simulations of
  landscapes.  Each conducts only a single generations worth of change}
\usage{
  rland <- advance.landscape(rland=l)
  rland <- carry.landscape(rland=l)
  rland <- extinct.landscape(rland=l)
  rland <- reproduce.landscape(rland=l)
  rland <- survive.landscape(rland=l)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\details{
  \code{advance.landscape()} merely advances the generation counter and selects
  the new generations demographic conditions if such conditions can
  vary.  The other functions implement carrying capacity, local
  extinction, reproduction, and survival/growth, respectively.  The
  function \code{simulate.landscape()} bundles the functionality of these
  components into a single function.
}

\seealso{
  \code{simulate.landscape}
  }
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  exampleland
  rm(exampleland)
}
\keyword{misc}

\eof
\name{demography.landscape}
\alias{demography.landscape}
\title{Calculate demographic parameters}

\description{
  Calculate demographic parameters from a landscape:  CURRENTLY BROKEN!}
\usage{
  rland <- demography.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\value{
  A list of length populations+1.  The first 1..populations elements
  are lists comprised of lambda, the equilibrium stage-structure, the
  actual stage structure, a $\chi^2$ value for the test of difference
  between predicted and actual, and an estimate of significance for that
  test.  The last element of the main list is the same as the previous
  ones except it refers to the entire landscape
  }
\seealso{
}
\keyword{misc}

\eof
\name{exp.het.landscape}
\alias{exp.het.landscape}
\title{Calculate expected heterozygosity}

\description{
  Calculate expected heterozygosity from a landscape}
\usage{
  hetmat <- exp.het.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\value{
A matrix with num loci columns and num populations rows.  Each element
reflects the expected heterozygosity for that population x locus combination  }
\details{
  Calculates the expected heterozygosity in each population:
  \deqn{1-\Sigma_{i_k} p_i^2}{1 - sum(p^2)}
  where \eqn{p} is a vector of allele frequencies for a locus in a population.
}
\seealso{
obs.het.landscape, Fst.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  exphet <- exp.het.landscape(exampleland)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{is.landscape}
\alias{is.landscape}
\title{Test whether an object is a (fairly) legitimate landscape}

\description{
  Test whether a genuine landscape}
\usage{
  is.landscape(Rland = NULL, verb = TRUE, exact = FALSE)
}
\arguments{
  \item{Rland}{the Rmetasim landscape object}
  \item{verb}{print why not a landscape}
  \item{exact}{more strict}
}

\examples{
  exampleland <- new.example.landscape()
  is.landscape(exampleland)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{island}
\docType{data}
\alias{island}
\title{rmetasim landscape containing an island migration structure}
\description{
This dataset consists of 10 populations arraged in an island
configuration.  It can be used to prototype functions that operate on
landscapes}
\usage{data(stepping)}
\format{A list in rmetasim landscape format}
\source{Fake data}
\keyword{datasets}

\eof
\name{landscape.locus}
\alias{landscape.locus}
\title{return a matrix containing genotypes for a particular locus}

\description{return a matrix containing genotypes for a particular locus
}
\usage{
  landscape.locus(lnum=1,Rland)
}
\arguments{
  \item{lnum}{the locus to return}
  \item{Rland}{the Rmetasim landscape object}
}


\value{
  matrix
}

\details{ Returns a matrix with rows = \code{dim(rland$individuals)[1]}.  The
first three columns correspond to the class (and two placeholder
variables) of an individual.  Here rland is a
  landscape object.  The remaining   columns (1 if haploid, 2 if
  diploid) contain the allele indices for the various loci}

\seealso{
  populations
  }
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  print("Allele frequencies at locus 1")
  table(landscape.locus(1,exampleland)[,c(-1,-2,-3)]) 
  rm(exampleland)
}
\keyword{misc}

\eof
\name{landscape.states}
\alias{landscape.states}
\alias{states}
\title{return a matrix containing actual genotypes for a particular locus}

\description{return a matrix containing the states of the alleles in genotypes for a particular locus
}
\usage{
  landscape.states(lnum=1,Rland)
}
\arguments{
  \item{lnum}{the locus to return}
  \item{Rland}{the Rmetasim landscape object}
}


\value{
  matrix
}

\details{ Returns a matrix with rows = \code{dim(rland$individuals)[1]}.  The
first three columns correspond to the class (and two placeholder
variables) of an individual.  Here rland is a
  landscape object.  The remaining   columns (1 if haploid, 2 if
  diploid) contain the states of the alleles for the selected loci}

\seealso{
  landscape.locus
  }
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  print("Allele frequencies at locus 1")
  table(landscape.locus(1,exampleland)[,c(-1,-2,-3)]) 
  rm(exampleland)
}
\keyword{misc}

\eof
\name{landscape.to.rtheta}
\alias{landscape.to.rtheta}
\title{Converts genetic marker data in a landscape into a format
suitable for analysis using ANOVA}

\description{
This function converts Rmetasim landscapes into a format that can be
analyzed with ANOVA to calculate Weir's theta.
}
\usage{
  genin <- landscape.to.rtheta(Rland,numi)
}
\arguments{
  \item{Rland}{the Rmetasim landscape object}
  \item{numi}{number of individuals to sample at random from each
  population/habitat.  The default value of 0 takes all individuals in
  each population.  CAUTION this could take a long time.  }
}
\value{
A matrix with columns representing the population, class, individual,
locus, allelic position, allele id.
}
\seealso{
popstruct
}

\keyword{misc}

\eof
\name{Genetic locus utilities}
\alias{locusvec}
\alias{ploidy}
\title{Provides convenient summarys of locus characteristics}

\description{return a vector of information about loci
}
\usage{
  locusvec(Rland)
  ploidy(Rland)
}
\arguments{
  \item{Rland}{the Rmetasim landscape object}
}


\value{
  vector
}

\details{\code{locusvec()} returns a vector that gives the numeric locus
ids for the columns in the \code{rland$individuals} matrix.
\code{ploidy()} returns a vector that gives the ploidy of each locus.}
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  locusvec(exampleland)
  ploidy(exampleland)
}
\keyword{misc}

\eof
\name{new.epoch}
\alias{new.epoch}
\title{Create an Epoch}

\description{
  Create an epoch for a Rmetasim landscape object}
\usage{
  ## must be called AFTER integer, switch, and float params have
  ##   been created and after the demography has been created
  ## S, R, and M matricies must be square matricies of size X by X
  ##   where X = rland$intparam$stages*rland$intparam$habitats

  rland <- new.epoch(rland,S=Smatrix,R=Rmatrix,M=Mmatrix,epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
}
\arguments{
  \item{rland}{partially created landscape object, required}
  \item{S}{(default=NULL) Survivablity matrix for epoch, NULL gives no movement between subpopulations (0 matrix)}
  \item{R}{(default=NULL) female Reproduction matrix for epoch, NULL gives no dispersal between subpopulations (0 matrix)}
  \item{M}{(default=NULL) Male reporduction matrix for epoch, NULL gives
    no sperm or pollen movement between subpopulations (0 matrix)}
  \item{epochprob}{(default=1) probability of choosing this epoch randomly if randepoch==1}
  \item{startgen}{(default=0) generation in which this epoch starts}
  \item{extinct}{(default=NULL) vector of extinction probabilities per
    generation for each subpopulation, must be rland$intparam$habitats
    in length, passing NULL gives a 0\% probability of extinction to each subpopulation}
    \item{carry}{(default=NULL) vector of carrying capacities for each subpopulation, must be rland$intparam$habitats in length, passing NULL gives a 1000 individual carrying capacity to each subpopulation}
    \item{localprob}{(default=NULL) vector of probabilites for choosing local demographies, must be length(rland$demography$localdem) in length, passing NULL gives each demography an equal probability}
}

  \examples{
  
  exampleS <- matrix(c(0.1, 0, 0.5, 0.3), nrow = 2)
  exampleR <- matrix(c(0, 1.1, 0, 0), nrow = 2)
  exampleM <- matrix(c(0, 0, 0, 1), nrow = 2)
  
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland, s=2, h=2)
  exampleland <- new.floatparam.land(exampleland)
  exampleland <- new.switchparam.land(exampleland)
  exampleland <- new.local.demo(exampleland,exampleS,exampleR,exampleM)

  ## nonsense matricies
  exampleS <- matrix(c(rep(0,4),
                rep(1,4),
                rep(0,4),
                rep(1,4)), nrow = 4)
  exampleR <- matrix(c(rep(0.5,4),
                rep(0,4),
                rep(0.5,4),
                rep(0,4)), nrow = 4)
  exampleM <- matrix(c(rep(0,4),
                rep(.25,4),
                rep(0,4),
                rep(0,4)), nrow = 4)

  ## defaults
  exampleland<- new.epoch(exampleland,exampleS,exampleR,exampleM)

  exampleland$demography$epochs[[1]]

  rm(exampleS)
  rm(exampleR)
  rm(exampleM)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.epoch.island}
\alias{new.epoch.island}
\title{Create an Island Model Epoch}

\description{
  Create an epoch for a Rmetasim landscape object that follows the
  conventions of the island model}
\usage{
  ## must be called AFTER integer, switch, and float params have
  ## been created and after the demography has been created

  rland <- new.epoch.island(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
                            epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
}
\arguments{
  \item{rland}{partially created landscape object, required}
  \item{s}{Rate of migration by individuals}
  \item{sfrom}{vector of lifecycle stages in which the individuals
    migrate from their current subpopulation, must be
    rland$intparam$stages in length}
  \item{sto}{vector of lifecycle stages in which the individuals arrive
    in a new subpopulation, must be rland$intparam$stages in length}
  \item{m}{Rate of migration by newborns}
  \item{mfrom}{vector of lifecycle stages in which the newborns leave
    their subpopulation, must be rland$intparam$stages in length}
  \item{mto}{vector of lifecycle stages in which the newborns arrive
    at their new subpopulation, must be rland$intparam$stages in length}
  \item{f}{Rate of sperm/pollen movement}
  \item{ffrom}{vector of lifecycle stages in which the males produce
    sperm/pollen, must be rland$intparam$stages in length}
  \item{fto}{???}
  \item{epochprob}{(default=1) probability of choosing this epoch randomly if randepoch==1}
  \item{startgen}{(default=0) generation in which this epoch starts}
  \item{extinct}{(default=NULL) vector of extinction probabilities per
    generation for each subpopulation, must be rland$intparam$habitats
    in length, passing NULL gives a 0\% probability of extinction to each subpopulation}
    \item{carry}{(default=NULL) vector of carrying capacities for each subpopulation, must be rland$intparam$habitats in length, passing NULL gives a 1000 individual carrying capacity to each subpopulation}
    \item{localprob}{(default=NULL) vector of probabilites for choosing local demographies, must be length(rland$demography$localdem) in length, passing NULL gives each demography an equal probability}
}

  \examples{
  
  exampleS <- matrix(c(0.1, 0, 0.5, 0.3), nrow = 2)
  exampleR <- matrix(c(0, 1.1, 0, 0), nrow = 2)
  exampleM <- matrix(c(0, 0, 0, 1), nrow = 2)
  
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland, s=2, h=2)
  exampleland <- new.floatparam.land(exampleland)
  exampleland <- new.switchparam.land(exampleland)
  exampleland <- new.local.demo(exampleland,exampleS,exampleR,exampleM)

  exampleland <- new.epoch.island(exampleland,.1,c(0,1),c(0,1),.3,c(0,1),c(1,0),.5,c(1,0),c(0,1))

  exampleland$demography$epochs[[1]]

  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.example.landscape}
\alias{new.example.landscape}
\title{Create a Default Landscape}

\description{
  Create a Rmetasim landscape with all default parameters.}
\usage{
  rland <- new.example.landscape()
}
\arguments{
  None
}
\examples{
  ## Only usage
  new.example.landscape()}
\keyword{misc}

\eof
\name{new.floatparam.land}
\alias{new.floatparam.land}
\title{Create a set of floating point parameters}

\description{
  Create a set of floating point parameters for a Rmetasim landscape.}
\usage{
  ## must be called AFTER new.landscape.empty()
  rland <- new.floatparam.land(rland,s=0)}
\arguments{
  \item{rland}{skeletion of landscape object, required}
  \item{s}{selfing (default=0), the selfing rate of the species}
}
\examples{
  ## Defaults
  exampleland <- new.landscape.empty()
  exampleland <- new.floatparam.land(exampleland)
  exampleland$floatparam

  ## .5 selfing rate
  exampleland <- new.landscape.empty()
  exampleland <- new.floatparam.land(exampleland,s=0.5)
  exampleland$floatparam

  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.individuals}
\alias{new.individuals}
\title{Fill a landscape with individuals}

\description{
  Create a set of individuals for a Rmetasim landscape object.}
\usage{
  ## must be called AFTER integer, switch, and float params, demography,
  ## epochs, and loci have been created

  rland <- new.individuals(rland,PopulationSizes)
}
\arguments{
  \item{rland}{nearly complete landscape object, required}
  \item{PopulationSizes}{vector of integers denoting how many
    individuals are in which stage and in which subpopulation, vector is
    ordered as: (pop1 stage1, pop1 stage2, ..., pop2 stage1, pop2stage2,
    ....),
    must be of length rland$intparam$habitats * rland$intparam$stages}
}
  \examples{
  
  exampleS <- matrix(c(0.1, 0, 0.5, 0.3), nrow = 2)
  exampleR <- matrix(c(0, 1.1, 0, 0), nrow = 2)
  exampleM <- matrix(c(0, 0, 0, 1), nrow = 2)
  
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland, s=2, h=2)
  exampleland <- new.floatparam.land(exampleland)
  exampleland <- new.switchparam.land(exampleland)
  exampleland <- new.local.demo(exampleland,exampleS,exampleR,exampleM)

  ## nonsense matricies
  exampleS <- matrix(c(rep(0,4),
                rep(1,4),
                rep(0,4),
                rep(1,4)), nrow = 4)
  exampleR <- matrix(c(rep(0.5,4),
                rep(0,4),
                rep(0.5,4),
                rep(0,4)), nrow = 4)
  exampleM <- matrix(c(rep(0,4),
                rep(.25,4),
                rep(0,4),
                rep(0,4)), nrow = 4)

  exampleland<- new.epoch(exampleland,exampleS,exampleR,exampleM)
  exampleland <- new.locus(exampleland,type=2,ploidy=2,mutationrate=.001,numalleles=5,allelesize=100)
  exampleland <- new.locus(exampleland,type=1,ploidy=1,mutationrate=.001,numalleles=3)
  exampleland <- new.locus(exampleland,type=0,ploidy=2,mutationrate=.004,numalleles=4)

  exampleland <- new.individuals(exampleland,
                 c(5,20,7,15))

  exampleland$individuals

  rm(exampleS)
  rm(exampleR)
  rm(exampleM)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.intparam.land}
\alias{new.intparam.land}
\title{Create a set of integer parameters}

\description{
  Create a set of integer parameters for a Rmetasim landscape.}
\usage{
  ## must be called AFTER new.landscape.empty()
  rland <- new.intparam.land(rland,h=2,s=1,cg=0,ce=0,totgen=500,maxland=10000)}
\arguments{
  \item{rland}{skeletion of landscape object, required}
  \item{h}{habitats (default=1), the number of different subpopulations within the landscape}
  \item{s}{stages (default=1), the number of stages in the life cycle of the organism}
  \item{cg}{currentgen (default=0), the current generation the simulation has reached}
  \item{ce}{currentepoch (default=0), the current epoch the simulation has reached}
  \item{totgen}{totoalgens (default=1000), the total number of generations to simulate}
  \item{maxland}{maxlandsize(default=200000), the maxium number of individuals that can exist in the simulation} 
}
\examples{
  ## Defaults
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland)
  exampleland$intparam

  ## 2 habitats, 3 stage lifecycle, 1000000 generations, maximum 1000000 individuals
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland,h=2,s=2,totgen=1000000,maxland=1000000)
  exampleland$intparam

  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.landscape.empty}
\alias{new.landscape.empty}
\title{Create a Skeletal Landscape}

\description{
  Create a skeletal Rmetasim landscape ready to be configured}
\usage{
  rland <- new.landscape.empty()
}
\arguments{
  None
}
\examples{
  ## Only usage
  new.landscape.empty()}
\keyword{misc}

\eof
\name{new.local.demo}
\alias{new.local.demo}
\title{Create a Local Demography}

\description{
  Create a local demography for an Rmetasim Landscape object}
\usage{
  ## must be called AFTER integer, switch, and float params have been created
  ## S, R, and M matricies must be square matricies of size rland$intparam$stages by rland$intparam$stages
  rland <- new.local.demo(rland,S=Smatrix,R=Rmatrix,M=Mmatrix)}
\arguments{
  \item{rland}{partially created landscape object, required}
  \item{S}{Survivablity matrix for demograpy, required}
  \item{R}{female Reproduction matrix for demography, required}
  \item{M}{Male reporduction matrix for demography, required}
}

\examples{
  
  exampleS <- matrix(c(0.1, 0, 0.5, 0.3), nrow = 2)
  exampleR <- matrix(c(0, 1.1, 0, 0), nrow = 2)
  exampleM <- matrix(c(0, 0, 0, 1), nrow = 2)
  
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland, s=2)
  exampleland <- new.floatparam.land(exampleland)
  exampleland <- new.switchparam.land(exampleland)
  exampleland <- new.local.demo(exampleland,exampleS,exampleR,exampleM)

  exampleland$demography$localdem

  rm(exampleS)
  rm(exampleR)
  rm(exampleM)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.locus}
\alias{new.locus}
\title{Add a locus}

\description{
  Add a locus to a Rmetasim landscape object}
\usage{
  ## must be called AFTER integer, switch, and float params have been created
  rland <- new.locus(rland,type=0,ploidy=1,mutationrate=0,transmission=1,numalleles=2,allelesize=50,frequencies=0)
}
\arguments{
  \item{rland}{partially created landscape object, required}
  \item{type}{(default=0) type of locus, 0=Infinite Allele mutation model (Integer), 1=Stepwise mutation model (Integer) state, 2=DNA base (variable length string state)}
  \item{ploidy}{(default=1) locus ploidy, 1 or 2}
  \item{mutationrate}{(default=0) probability of mutation per generation, less than or equal to 1}
  \item{transmission}{(default=1) 1=uniparental inheritance, 0=biparental inheritance}
  \item{numalleles}{(default=2) number of different alleles at the time of creation}
  \item{allelesize}{(default=50) length of DNA strings if type=2}
  \item{frequencies}{(default=NULL) vector of frequencies for each allele, must be numalleles long and add up to 1, if NULL frequencies are equally distributed}
}

\examples{
  exampleland <- new.landscape.empty()
  exampleland <- new.intparam.land(exampleland, s=2, h=2)
  exampleland <- new.floatparam.land(exampleland)
  exampleland <- new.switchparam.land(exampleland)

  exampleland <- new.locus(exampleland,type=2,ploidy=2,mutationrate=.001,numalleles=5,allelesize=100)

  exampleland$loci

  rm(exampleland)
}
\keyword{misc}

\eof
\name{new.switchparam.land}
\alias{new.switchparam.land}
\title{Create a set of boolean parameters}

\description{
  Create a set of boolean (1 or 0) parameters for a Rmetasim landscape.}
\usage{
  ## must be called AFTER new.landscape.empty()
  rland <- new.switchparam.land(rland,re=1,rd=1,mp=1)}
\arguments{
  \item{rland}{skeletion of landscape object, required}
  \item{re}{randepoch (default=0), 1=randomly pick a new epoch (from the
    epochs listed in the landscape) after an epoch completes, 0=epochs
    are chosen in order}
  \item{rd}{randdemo (default=0), 1=randomly choose a demography (from the demographies listed in the landscape) for each subpopulation, 0=demographies are assigned in order}
  \item{mp}{multp (defualt=1), 1=multiple paternity,0=entire families from a single mating}
}

\examples{
  ## Defaults
  exampleland <- new.landscape.empty()
  exampleland <- new.switchparam.land(exampleland)
  exampleland$switchparam

  ## Random epochs, random demographies, and no multiple paternity
  exampleland <- new.landscape.empty()
  exampleland <- new.switchparam.land(exampleland,re=1,rd=1,mp=0)
  exampleland$switchparam

  rm(exampleland)
}
\keyword{misc}

\eof
\name{obs.het.landscape}
\alias{obs.het.landscape}
\title{Calculate observed heterozygosity}

\description{
  Calculate observed heterozygosity from a landscape}
\usage{
  hetmat <- obs.het.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\value{
A matrix with num loci columns and num populations rows.  Each element
reflects the observed heterozygosity for that population x locus combination  }

\seealso{
exp.het.landscape, Fst.landscape
}

\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  obshet <- obs.het.landscape(exampleland)
  rm(exampleland)
}
\keyword{misc}

\eof
\name{popstruct}
\alias{popstruct}
\title{Calculates Weir and Cokerham's theta}

\description{
Takes data in the format returned by \code{landscape.to.rtheta()} and
returns estimates of Fst in the form of theta }

\usage{
  thetamat <- popstruct(genin)
}
\arguments{
  \item{genin}{a dataframe or matrix with columns corresponding to
  population, class, individual, locus, allelic position, and allele
  ID.  The matrix is most easily generated by using the function
  \code{landscape.to.rtheta()}}
}

\value{
A matrix with two columns.  One gives estimates of theta and the other
estimates of F-hat.  Rows correspond to the different loci.
}
\details{
Calculates theta using a nested analysis of variance approach first
outlined by Weir and Cockerham in 1984}

\seealso{
Fst.landscape, landscape.to.rtheta
}


\keyword{misc}

\eof
\name{populations}
\alias{populations}
\title{return a vector of population IDs from a landscape}

\description{return a vector of population IDs from a landscape
}
\usage{
  populations(Rland)
}
\arguments{
  \item{Rland}{the Rmetasim landscape object}
}


\value{
  a vector
}
\details{  Returns a vector of length \code{dim(rland$individuals)[1]} where rland is a
  landscape object.  The vector classifies individuals into populations
  (or habitats)  }

\seealso{
  locus
  }
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  hist(populations(exampleland),main="Distribution of population size in landscape")
  rm(exampleland)
}
\keyword{misc}

\eof
\name{read.landscape}
\alias{read.landscape}
\title{Load a landscape from a file}

\description{
  Load a Rmetasim landscape from a file into an R object.}
\usage{
  rland <- read.landscape(fn="mylandscape.lnd")}
\arguments{
  \item{fn}{the path and name of the file containing the landscape}
}

\examples{
  ## Needs write access to the current directory, files created!!
  write.landscape(new.example.landscape(), "exampleland.lnd")
  exampleland <- read.landscape("exampleland.lnd")
  exampleland
  rm(exampleland)
}
\keyword{misc}

\eof
\name{simulate.landscape}
\alias{simulate.landscape}
\title{Run a simulation for a single landscape through time}

\description{
  Simulate a Rmetasim landscape for a number of generations.}
\usage{
  rland <- simulate.landscape(rland=l,numit=100,seed=-1,compress=FALSE,adj.lambda=0)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{numit}{the number of generations/iterations to simulate, note that
    landscapes will not run past the rland$intparam$totalgens value}
  \item{seed}{The default value of seed uses the seed set in the
    calling environment.  Any other value for seed uses 'set.seed()' to
    reset the random number generator.  simulate.landscape uses the RNG
    selected by the
    calling environment.}
  \item{compress}{If true, simulate.landscape executes a survival and carrying
    capacity step before returning.  In demographies with high
    reproductive potential, this can significantly reduce the size of R
    objects returned}
  \item{adj.lambda}{Tries to apply a correction to population growth
  that makes the observed growth rate more closely approximate that
  predicted from standard analysis of the Lefkovitch matrices}
}

\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)
  exampleland
  rm(exampleland)
}
\keyword{misc}

\eof
\name{theta.h.landscape}
\alias{theta.h.landscape}
\title{Calculate theta using heterozygosity}

\description{Calculate theta from a landscape based upon
  heterozygosity.}

\usage{
 theta.h.mat <- theta.h.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\details{Uses routines in the package 'ape'}
  
\value{
A matrix with num loci columns and num populations rows.  Each element
reflects the estimated theta for that population x locus combination  }
\seealso{
theta.k.landscape, theta.s.landscape
}
\examples{

  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)

  library(ape)
  theta.h.mat <- theta.h.landscape(exampleland)
  theta.h.mat
}
\keyword{misc}

\eof
\name{theta.k.landscape}
\alias{theta.k.landscape}
\title{Calculate theta using the number of alleles}

\description{
  Calculate theta using number of alleles from a landscape.}
\usage{
 theta.k.mat <- theta.k.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\details{Uses routines in the package 'ape'}
\value{
A matrix with num loci columns and num populations rows.  Each element
reflects the estimated theta for that population x locus combination  }
\seealso{
theta.h.landscape, theta.s.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)

  library(ape)
  theta.k.mat <- theta.k.landscape(exampleland)
  theta.k.mat
}
\keyword{misc}

\eof
\name{theta.s.landscape}
\alias{theta.s.landscape}
\title{Calculate theta using segregating sites}

\description{Calculate theta from a landscape based upon
  the number of seqregating sites.}

\usage{
 theta.s.mat <- theta.s.landscape(rland)
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
}
\details{Uses routines in the package 'ape'}
  
\value{
A matrix with num loci columns and num populations rows.  Each element
reflects the estimated theta for that population x locus combination  }
\seealso{
theta.k.landscape, theta.h.landscape
}
\examples{
  exampleland <- new.example.landscape()
  exampleland <- simulate.landscape(exampleland, 4)

  library(ape)
  theta.s.mat <- theta.s.landscape(exampleland)
  theta.s.mat
}
\keyword{misc}

\eof
\name{write.landscape}
\alias{write.landscape}
\title{Save a landscape to a file}

\description{
  Save a Rmetasim landscape object to a file}
\usage{
  rland <- write.landscape(rland=l,fn="mylandscape.lnd")
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{fn}{the path and name of the file to save the landscape to}
}

\examples{
  ## Needs write access to the current directory, files created!!
  exampleland <- new.example.landscape()
  write.landscape(exampleland, "exampleland.lnd")

  rm(exampleland)
}
\keyword{misc}

\eof
\name{write.landscape.foreign}
\alias{write.landscape.foreign}
\title{Save a landscape to a file in a foreign format}

\description{
  Save a Rmetasim landscape object to a file in a suite of output formats
}
\usage{
  rland <- write.landscape.foreign(rland,fn="foreign",numi=24,fmt="GDA")
}
\arguments{
  \item{rland}{the Rmetasim landscape object}
  \item{fn}{the path and name of the file to save the landscape
    to}
  \item{numi}{number of individuals sampled per population for
      inclusion in subsequent analyses}
  \item{fmt}{the output format for the landscape:  Can take the
    following values:"arlequin","arlequinhap","biosys","genpop","R","migrate","rerat","GDA"}
}

\examples{
  ## Needs write access to the current directory, files created!!
  exampleland <- new.example.landscape()
  write.landscape.foreign(exampleland, fn="exampleland.nex", fmt="GDA")
  rm(exampleland)
}
\keyword{misc}

\eof
